@@ -3,6 +3,8 @@ import os
 
 from ZPublisher.HTTPRequest import BaseRequest
 from zope.publisher.browser import BrowserView
+from Products.CMFCore.FSPageTemplate import FSPageTemplate
+from Products.PythonScripts.PythonScript import PythonScript
 from Products.Archetypes.interfaces import IBaseObject
 from Products.CMFPlone.Portal import PloneSite
 
@@ -15,7 +17,7 @@ def wrappedTraverse(self, path, response=None, validated_hook=None):
 
     extentions = ('.jpg', '.gif', '.png', '.js', '.class', '.css')
     
-    if isinstance(traverse, BrowserView):
+    if isinstance(traverse, (BrowserView, FSPageTemplate, PythonScript)):
         obj = traverse.aq_parent
     else:
         obj = traverse
